<?php
/**
 * Elementor Active
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Main keeway_Elementor_Active_Extension Class
 *
 * The main class that initiates and runs the plugin.
 *
 * @since 1.0.0
 */
final class keeway_Elementor_Active_Extension {

	/**
	 * Plugin Version
	 *
	 * @since 1.0.0
	 *
	 * @var string The plugin version.
	 */
	const VERSION = '1.0.0';

	/**
	 * Minimum Elementor Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum Elementor version required to run the plugin.
	 */
	const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

	/**
	 * Minimum PHP Version
	 *
	 * @since 1.0.0
	 *
	 * @var string Minimum PHP version required to run the plugin.
	 */
	const MINIMUM_PHP_VERSION = '5.6';

	/**
	 * Instance
	 *
	 * @since 1.0.0
	 *
	 * @access private
	 * @static
	 *
	 * @var keeway_Elementor_Active_Extension The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 * @static
	 *
	 * @return keeway_Elementor_Active_Extension An instance of the class.
	 */
	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;

	}

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function __construct() {


		add_action( 'plugins_loaded', [ $this, 'init' ] );

	}



	/**
	 * Initialize the plugin
	 *
	 * Load the plugin only after Elementor (and other plugins) are loaded.
	 * Checks for basic plugin requirements, if one check fail don't continue,
	 * if all check have passed load the files required to run the plugin.
	 *
	 * Fired by `plugins_loaded` action hook.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init() {

		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
			return;
		}

		// Add Plugin actions
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'init_widgets' ] );

	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have Elementor installed or activated.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_missing_main_plugin() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor */
			esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'keeway' ),
			'<strong>' . esc_html__( 'Keeway Plugin', 'keeway' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'keeway' ) . '</strong>'
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required Elementor version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'keeway' ),
			'<strong>' . esc_html__( 'Keeway Plugin', 'keeway' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'keeway' ) . '</strong>',
			 self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Admin notice
	 *
	 * Warning when the site doesn't have a minimum required PHP version.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function admin_notice_minimum_php_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'keeway' ),
			'<strong>' . esc_html__( 'Keeway Plugin', 'keeway' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'keeway' ) . '</strong>',
			 self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	/**
	 * Init Widgets
	 *
	 * Include widgets files and register them
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 */
	public function init_widgets() {

		// Include Widget files

		require_once( __DIR__ . '/elementor/title.php' );
		require_once( __DIR__ . '/elementor/features.php' );
		require_once( __DIR__ . '/elementor/skill.php' );
		require_once( __DIR__ . '/elementor/skill_content.php' );
		require_once( __DIR__ . '/elementor/why_choose.php' );
		require_once( __DIR__ . '/elementor/services.php' );
		require_once( __DIR__ . '/elementor/works.php' );
		require_once( __DIR__ . '/elementor/counter.php' );
		require_once( __DIR__ . '/elementor/video.php' );
		require_once( __DIR__ . '/elementor/team.php' );
		require_once( __DIR__ . '/elementor/newsletter.php' );
		require_once( __DIR__ . '/elementor/pricing.php' );
		require_once( __DIR__ . '/elementor/testimonials.php' );
		require_once( __DIR__ . '/elementor/partners.php' );
		require_once( __DIR__ . '/elementor/blog.php' );
		require_once( __DIR__ . '/elementor/contact-us.php' );


		// Register widget


		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayTitleWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayFeaturesWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewaySkillWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewaySkillContentWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayWhyChooseWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayServicesWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayWorksWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayCounterWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayVideoWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayTeamWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayNewsletterWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayPricingWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayTestimonialsWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayPartnersWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayBlogWidget() );	
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new \KeewayContactUsWidget() );	

	}


}

keeway_Elementor_Active_Extension::instance();